//! AIOS v2 Kernel - Using bootloader crate

#![no_std]
#![no_main]

use core::panic::PanicInfo;

// Simple VGA buffer writer
struct VgaBuffer {
    chars: [[u16; 80]; 25],
}

static mut VGA_BUFFER: *mut VgaBuffer = 0xb8000 as *mut VgaBuffer;

fn print_char(c: u8, x: usize, y: usize) {
    unsafe {
        let vga = &mut *VGA_BUFFER;
        vga.chars[y][x] = (0x0f << 8) | (c as u16);
    }
}

fn print_str(s: &str, x: usize, y: usize) {
    for (i, byte) in s.bytes().enumerate() {
        print_char(byte, x + i, y);
    }
}

// Entry point
#[no_mangle]
pub extern "C" fn _start() -> ! {
    // Clear screen
    for y in 0..25 {
        for x in 0..80 {
            print_char(b' ', x, y);
        }
    }
    
    // Print welcome message
    print_str("AIOS v2 - AI Operating System", 25, 12);
    print_str("Kernel started successfully!", 26, 13);
    
    loop {
        unsafe {
            core::arch::asm!("hlt");
        }
    }
}

// Panic handler
#[panic_handler]
fn panic(_info: &PanicInfo) -> ! {
    print_str("KERNEL PANIC!", 33, 15);
    loop {
        unsafe {
            core::arch::asm!("hlt");
        }
    }
}